@@ -5,7 +5,7 @@ from functools import partial
 import pandas as pd
 from pydeflate import exchange, deflate, set_pydeflate_path
 
-from oda_data import config
+from oda_data.config import OdaPATHS
 from oda_data.logger import logger
 
 
@@ -89,7 +89,6 @@ def clean_raw_df(
 
 
 # Set the path for the pydeflate package to store its raw data
-global OdaPATHS
 set_pydeflate_path(OdaPATHS.pydeflate)
 
 # Create a helper function to consistently exchange data
